@@ -1,24 +1,24 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2017-06-10 18:20:31 michl>
+# Last changed Time-stamp: <2015-02-11 17:03:30 mtw>
 
 package Bio::ViennaNGS::Bam;
 
+use Exporter;
+use version; our $VERSION = qv('0.12');
 use strict;
 use warnings;
-use Exporter;
-use Bio::ViennaNGS;
+use Bio::Perl 1.00690001;
 use Bio::DB::Sam 1.37;
 use Data::Dumper;
 use File::Basename qw(fileparse);
 use File::Temp qw(tempfile);
 use Path::Class;
 use Carp;
-use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 our @ISA = qw(Exporter);
 our @EXPORT = ();
 
-our @EXPORT_OK = qw ( split_bam uniquify_bam uniquify_bam2 );
+our @EXPORT_OK = qw ( split_bam uniquify_bam );
 
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 #^^^^^^^^^^^ Subroutines ^^^^^^^^^^#
@@ -28,7 +28,7 @@ sub split_bam {
   my %data = ();
   my @NHval = ();
   my @processed_files = ();
-  my ($verbose,$nh_warning_issued) = (0)x2;
+  my $verbose = 0;
   my ($bamfile,$reverse,$want_uniq,$want_bed,$dest_dir,$log) = @_;
   my ($bam,$sam,$bn,$path,$ext,$header,$flag,$NH,$eff_strand,$tmp);
   my ($bam_pos,$bam_neg,$tmp_bam_pos,$tmp_bam_neg,$bamname_pos,$bamname_neg);
@@ -46,18 +46,17 @@ sub split_bam {
 		       se_alis   => 0,
 		       pe_alis   => 0,
 		       flag      => 0,
-		       unmapped  => 0,
 		      );
   $data{count} = \%count_entries;
   $data{flag} = ();
-  $data{nh_issues} = 0; # will be set to 1 if NH attribute is missing
-  $nh_warning_issued = 0;
 
   croak "ERROR [$this_function] $bamfile does not exist\n"
     unless (-e $bamfile);
   croak "ERROR [$this_function] $dest_dir does not exist\n"
     unless (-d $dest_dir);
 
+  open(LOG, ">", $log) or croak $!;
+
   (undef,$tmp_bam_pos) = tempfile('BAM_POS_XXXXXXX',UNLINK=>0);
   (undef,$tmp_bam_neg) = tempfile('BAM_NEG_XXXXXXX',UNLINK=>0);
 
@@ -89,40 +88,27 @@ sub split_bam {
   while (my $read= $bam->read1() ) {
     @NHval = ();
     $data{count}{total}++;
-
-    # collect statistics of SAM flags
-    $flag = $read->flag;
-    unless (exists $data{flag}{$flag}){
-      $data{flag}{$flag} = 0;
-    }
-    $data{flag}{$flag}++;
-
-    # skip unmapped reads
-    if ( $read->get_tag_values('UNMAPPED') ){
-      $data{count}{unmapped}++;
-      next;
-    }
+    if($verbose == 1){print STDERR $read->query->name."\t";}
 
     # check if NH (the SAM tag used to indicate multiple mappings) is set
     if ($read->has_tag("NH")) {
       @NHval = $read->get_tag_values("NH");
       $NH = $NHval[0];
-      if ($NH == 1) {$data{count}{uniq}++;}
+      if ($NH == 1) {
+	$data{count}{uniq}++;
+	if ($verbose == 1) {print STDERR "NH:i:1\t";}
+      }
       else {
 	$data{count}{mult}++;
+	if ($verbose == 1) {print STDERR "NH:i:".$NH."\t";}
 	if ($want_uniq == 1) { # skip processing this read if it is a mutli-mapper
 	  $data{count}{skip}++;
 	  next;
 	}
       }
+      $data{count}{cur}++;
     }
-    else{ # no NH tag found
-      $data{nh_issues} = 1; # set this once and for all
-      unless ($nh_warning_issued == 1){
-	carp "WARN [$this_function] Read ".$read->query->name." does not have NH attribute\n";
-	$nh_warning_issued = 1;
-      }
-    }
+    else{ carp "WARN [$this_function] Read ".$read->query->name." does not have NH attribute\n";}
 
   #  print Dumper ($read->query);
     $strand = $read->strand;
@@ -224,9 +210,13 @@ sub split_bam {
     }
     if($verbose == 1) {print STDERR "--> ".$eff_strand."\t";}
 
-    # count considered reads
-    $data{count}{cur}++;
-
+    # collect statistics of SAM flags
+    $flag = $read->flag;
+    unless (exists $data{flag}{$flag}){
+      $data{flag}{$flag} = 0;
+    }
+    $data{flag}{$flag}++;
+    if ($verbose == 1) {print STDERR "\n";}
   } # end while
 
   rename ($tmp_bam_pos, $bamname_pos);
@@ -239,7 +229,7 @@ sub split_bam {
 
   # error checks
   unless ($data{count}{pe_alis} + $data{count}{se_alis} == $data{count}{cur}) {
-    printf "ERROR:  paired-end + single-end != total alignments\n";
+    printf "ERROR:  paired-end + single-end alignments != total alignment count\n";
     print Dumper(\%data);
     croak $!;
   }
@@ -247,8 +237,7 @@ sub split_bam {
     printf STDERR "%20d fragments on [+] strand\n",$data{count}{pos};
     printf STDERR "%20d fragments on [-] strand\n",$data{count}{neg};
     printf STDERR "%20d sum\n",eval($data{count}{pos}+$data{count}{neg});
-    printf STDERR "%20d unmapped reads\n",$data{count}{unmapped};
-    printf STDERR "%20d total alignment/read count\n",$data{count}{cur};
+    printf STDERR "%20d cur_count (should be)\n",$data{count}{cur};
     printf STDERR "ERROR: pos alignments + neg alignments != total alignments\n";
     print Dumper(\%data);
     croak $!;
@@ -256,43 +245,30 @@ sub split_bam {
   foreach (keys %{$data{flag}}){
     $data{count}{flag} += $data{flag}{$_};
   }
-  unless ($data{count}{flag} == $data{count}{cur} + $data{count}{unmapped}){
+  unless ($data{count}{flag} == $data{count}{cur}){
     printf STDERR "%20d alignments considered\n",$data{count}{cur};
-    printf STDERR "%20d unmapped reads\n",$data{count}{unmapped};
     printf STDERR "%20d alignments found in flag statistics\n",$data{count}{flag};
-    printf STDERR "ERROR: alignments considered + unmapped reads != alignments from flag stat\n";
+    printf STDERR "ERROR: #considered alignments != #alignments from flag stat\n";
     print Dumper(\%data);
     croak $!;
   }
 
   # logging output
-  open(LOG, ">", $log) or croak $!;
   printf LOG "# bam_split.pl log for file \'$bamfile\'\n";
   printf LOG "#-----------------------------------------------------------------\n";
-  printf LOG "%20d total alignments (unique/multi/unmapped)\n",$data{count}{total};
-  printf LOG "%20d unique-mappers   (%7.2f%% of total) ",
-    $data{count}{uniq},eval(100*$data{count}{uniq}/$data{count}{total});
-  if ($data{nh_issues}){printf LOG " *** NH attribute issues ***";}
-  printf LOG "\n";
-  printf LOG "%20d multi-mappers    (%7.2f%% of total) ",
+  printf LOG "%20d total alignments (unique & multi-mapper)\n",$data{count}{total};
+  printf LOG "%20d unique-mappers (%6.2f%% of total)\n",
+    $data{count}{uniq},eval(100*$data{count}{uniq}/$data{count}{total}) ;
+  printf LOG "%20d multi-mappers  (%6.2f%% of total)\n",
     $data{count}{mult},eval(100*$data{count}{mult}/$data{count}{total});
-  if ($data{nh_issues}){printf LOG " *** NH attribute issues ***";}
-  printf LOG "\n";
-  printf LOG "%20d skipped\n", $data{count}{skip};
+  printf LOG "%20d multi-mappers skipped\n", $data{count}{skip};
   printf LOG "%20d alignments considered\n", $data{count}{cur};
   printf LOG "%20d paired-end\n", $data{count}{pe_alis};
   printf LOG "%20s single-end\n", $data{count}{se_alis};
-  if($data{count}{cur}>0){
-    printf LOG "%20d fragments on [+] strand  (%7.2f%% of considered)\n",
-      $data{count}{pos},eval(100*$data{count}{pos}/$data{count}{cur});
-    printf LOG "%20d fragments on [-] strand  (%7.2f%% of considered)\n",
-      $data{count}{neg},eval(100*$data{count}{neg}/$data{count}{cur});
-  }
-  else{
-     printf LOG "%20d fragments on [+] strand\n",$data{count}{pos};
-     printf LOG "%20d fragments on [-] strand\n",$data{count}{neg};
-  }
-  printf LOG "%20d unmapped\n", $data{count}{unmapped};
+  printf LOG "%20d fragments on [+] strand  (%6.2f%% of considered)\n",
+    $data{count}{pos},eval(100*$data{count}{pos}/$data{count}{cur});
+  printf LOG "%20d fragments on [-] strand  (%6.2f%% of considered)\n",
+    $data{count}{neg},eval(100*$data{count}{neg}/$data{count}{cur});
   printf LOG "#-----------------------------------------------------------------\n";
   printf LOG "Dumper output:\n". Dumper(\%data);
   close(LOG);
@@ -300,23 +276,12 @@ sub split_bam {
 }
 
 sub uniquify_bam {
-  my %data = ();
   my ($bamfile,$dest,$log) = @_;
   my ($bam, $bn,$path,$ext,$read,$header);
-  my ($tmp_uniq,$tmp_mult,$fn_uniq,$fn_mult,$bam_uniq,$bam_mult,$NH);
-  my ($count_all,$count_uniq,$count_mult,$unmapped,$nh_warning_issued) = (0)x5;
+  my ($tmp_uniq,$tmp_mult,$fn_uniq,$fn_mult,$bam_uniq,$bam_mult);
+  my ($count_all,$count_uniq,$count_mult) = (0)x3;
   my @processed_files = ();
-  my @NHval = ();
   my $this_function = (caller(0))[3];
-  my %count_entries = (
-		       total     => 0,
-		       uniq      => 0,
-		       mult      => 0,
-		       unmapped  => 0,
-		       nonhtag   => 0,
-		      );
-  $data{count} = \%count_entries;
-  $data{nh_issues} = 0; # will be set to 1 if NH attribute is missing
 
   croak "ERROR [$this_function] Cannot find $bamfile\n"
     unless (-e $bamfile);
@@ -341,46 +306,19 @@ sub uniquify_bam {
   $bam_mult->header_write($header);
 
   while ($read = $bam->read1() ) {
-    $data{count}{total}++;
-
-    # skip unmapped reads
-    if ( $read->get_tag_values('UNMAPPED') ){
-      $data{count}{unmapped}++;
-      next;
+    $count_all++;
+    if ($read->aux_get("NH") == 1){ # uniquely mapped reads
+      $bam_uniq->write1($read);
+      $count_uniq++;
     }
-
-    # check if NH (the SAM tag used to indicate multiple mappings) is set
-    if ($read->has_tag("NH")) {
-      @NHval = $read->get_tag_values("NH");
-      $NH = $NHval[0];
-      if ($NH == 1) {
-	$bam_uniq->write1($read);
-	$data{count}{uniq}++;
-      }
-      else {
-	$bam_mult->write1($read);
-	$data{count}{mult}++;
-      }
-    }
-    else{ # no NH tag found
-      $data{nh_issues} = 1; # set this once and for all
-      unless ($nh_warning_issued == 1){
-	$data{count}{nonhtag}++;
-	carp "ERROR [$this_function] Read ".$read->query->name.
-	  " does not have NH attribute\nCannot continue ...";
-	$nh_warning_issued = 1;
-      }
+    else { # multiply mapped reads
+      $bam_mult->write1($read);
+      $count_mult++;
     }
   }
 
-  unless ($data{count}{uniq} + $data{count}{mult} ==
-	  $data{count}{total} - $data{count}{unmapped} - $data{count}{nonhtag}){
-    printf STDERR "%20d unique alignments\n",$data{count}{uniq};
-    printf STDERR "%20d multiple alignments\n",$data{count}{mult};
-    printf STDERR "%20d total alignments\n",$data{count}{total};
-    printf STDERR "%20d unmapped reads\n",$data{count}{unmapped};
-    croak "ERROR [$this_function] Read counts don't match\n";
-  }
+  croak "ERROR [$this_function] Read counts don't match\n"
+    unless ($count_uniq + $count_mult == $count_all);
 
   rename ($tmp_uniq, $fn_uniq);
   rename ($tmp_mult, $fn_mult);
@@ -388,142 +326,9 @@ sub uniquify_bam {
 
   if (defined $log){
     my $lf = file($dest,$log);
-    open(LOG, ">", $lf) or croak $!;
-    printf LOG "%15d reads total\n%15d unique alignments\n%15d multiple alignments\n%15d unmapped\n",
-      $data{count}{total},$data{count}{uniq},$data{count}{mult},$data{count}{unmapped};
-    close(LOG);
-  }
-}
-
-sub uniquify_bam2 {
-  my %data = ();
-  my ($bamfile,$dest,$log) = @_;
-  my ($bam, $bn,$path,$ext,$read,$header,$ali);
-  my ($tmp_uniq,$tmp_mult,$fn_uniq,$fn_mult,$bam_uniq,$bam_mult,$NH);
-  my ($count_all,$count_uniq,$count_mult,$unmapped,$nh_warning_issued) = (0)x5;
-  my $pushme = 0;
-  my $allgomulti = 0;
-  my @processed_files = ();
-  my @NHval = ();
-  my $lastqname = undef;
-  my @band = ();
-  my $this_function = (caller(0))[3];
-  my %count_entries = (
-		       total     => 0,
-		       uniq      => 0,
-		       mult      => 0,
-		       unmapped  => 0,
-		       nonhtag   => 0,
-		      );
-  $data{count} = \%count_entries;
-  $data{nh_issues} = 0; # will be set to 1 if NH attribute is missing
-
-  croak "ERROR [$this_function] Cannot find $bamfile\n"
-    unless (-e $bamfile);
-  croak "ERROR [$this_function] $dest does not exist\n"
-    unless (-d $dest);
-
-  ($bn,$path,$ext) = fileparse($bamfile, qr /\..*/);
-
-  (undef,$tmp_uniq) = tempfile('BAM_UNIQ_XXXXXXX',UNLINK=>0);
-  (undef,$tmp_mult) = tempfile('BAM_MULT_XXXXXXX',UNLINK=>0);
-
-  $bam     = Bio::DB::Bam->open($bamfile, "r");
-  $fn_uniq = file($dest,$bn.".uniq.band.".$ext);
-  $fn_mult = file($dest,$bn.".mult.band.".$ext);
-  $header  = $bam->header; # TODO: modify header, leave traces ...
-
-  $bam_uniq = Bio::DB::Bam->open($tmp_uniq,'w')
-    or croak "ERROR [$this_function] Cannot open temp file for writing: $!";
-  $bam_mult = Bio::DB::Bam->open($tmp_mult,'w')
-    or croak "ERROR [$this_function] Cannot open temp file for writing: $!";
-  $bam_uniq->header_write($header);
-  $bam_mult->header_write($header);
-
-  while ($read = $bam->read1() ) {
-    $data{count}{total}++;
-
-    # skip unmapped reads
-    if ( $read->get_tag_values('UNMAPPED') ){
-      $data{count}{unmapped}++;
-      next;
-    }
-
-    my $qname = $read->qname;
-    $qname =~ s/\/[12]$//;
-
-    if (!defined($lastqname) || $qname eq $lastqname ){
-      #print "$qname\n";
-      push @band, $read;
-    }
-    else {
-      # band is now completely read, processing it ...
-      foreach $ali (@band){
-	# check if NH (the SAM attribute used to indicate multiple mappings) is set
-	if ($ali->has_tag("NH")) {
-	  @NHval = $ali->get_tag_values("NH");
-	  $NH = $NHval[0];
-	  if ($NH > 1) {
-	    $allgomulti = 1;
-	    $data{count}{mult}++;
-	  }
-	  else {
-	    $data{count}{uniq}++;
-	  }
-	}
-	else{ # no NH tag found
-	  $data{nh_issues} = 1; # set this once and for all
-	  unless ($nh_warning_issued == 1){
-	    $data{count}{nonhtag}++;
-	    carp "ERROR [$this_function] Read ".$read->qname.
-	      " does not have NH attribute\nCannot continue ...";
-	    $nh_warning_issued = 1;
-	  }
-	}
-      } # end foreach
-
-      if ($allgomulti == 1){ # write entire band to multi mapper file
-	foreach $ali (@band){$bam_mult->write1($ali)}
-	#print " -> mult\n";
-      }
-      else{ # write entire band to uniq mapper file
-	foreach $ali (@band){$bam_uniq->write1($ali)}
-	#print " -> uniq\n";
-      }
-
-      #print "-----\n";
-      @band = ();
-      $pushme = 1;
-      $allgomulti = 0;
-    } # end else
-
-    if ($pushme == 1){
-      #print "$qname\n";
-      push @band, $read;
-      $pushme = 0;
-    }
-
-    $lastqname = $qname;
-  }
-
-  unless ($data{count}{uniq} + $data{count}{mult} ==
-  	  $data{count}{total} - $data{count}{unmapped} - $data{count}{nonhtag}){
-    printf STDERR "%20d unique alignments\n",$data{count}{uniq};
-    printf STDERR "%20d multiple alignments\n",$data{count}{mult};
-    printf STDERR "%20d total alignments\n",$data{count}{total};
-    printf STDERR "%20d unmapped reads\n",$data{count}{unmapped};
-    croak "ERROR [$this_function] Read counts don't match\n";
-  }
-
-  rename ($tmp_uniq, $fn_uniq);
-  rename ($tmp_mult, $fn_mult);
-  push (@processed_files, ($fn_uniq,$fn_mult));
-
-  if (defined $log){
-    my $lf = file($dest,$log);
-    open(LOG, ">", $lf) or croak $!;
-    printf LOG "%15d reads total\n%15d unique alignments\n%15d multiple alignments\n%15d unmapped\n",
-      $data{count}{total},$data{count}{uniq},$data{count}{mult},$data{count}{unmapped};
+    open(LOG, ">>", $lf) or croak $!;
+    printf LOG "%15d reads total\n%15d unique reads\n%15d multiple reads\n",
+      $count_all,$count_uniq,$count_mult;
     close(LOG);
   }
 }
@@ -585,7 +390,7 @@ This routine returns an array whose fist two elements are the file
 names of the newly generate BAM files with reads mapped to the
 positive, and negative strand, respectively. Elements three and four
 are the number of fragments mapped to the positive and negative
-strand. If the C<$want_bed> option was given elements five and six are
+strand. If the C<$want_bed> option was given elements fiveand six are
 the file names of the output BED files for positive and negative
 strand, respectively.
 
@@ -595,12 +400,6 @@ separately, thus allowing for scenarios where eg. one read is a
 multi-mapper, whereas its associate mate is a unique mapper, resulting
 in an ambiguous alignment of the entire fragment.
 
-As mentioned above, the NH:i: SAM attribute is used for discriminating
-unique and multi mappers, thus requiring this attribute to be present
-in every SAM record. If this attribute is not found in I<all> SAM
-entries, a warning will be issued and the log file will contain a note
-indicating that there were issues with the NH attribute.
-
 =item uniquify_bam($bam,$dest,$log)
 
 Extract I<uniquely> and I<multiply> aligned reads from BAM file
@@ -617,29 +416,12 @@ NOTE: Not all short read mappers use the I<NH:i:> SAM attribute to
 decorate unique and multi mappers. As such, this routine will not work
 unless your BAM file has these attributes.
 
-=item uniquify_bam2($bam,$dest,$log)
-
-Extract I<uniquely> and I<multiply> aligned reads from BAM file
-C<$bam> by means of the I<NH:i:> SAM attribute, like the original
-C<uniquify_bam> routine. Contrary to that, this one expects a
-I<name-sorted BAM file> and reads in bands of (supposedly paired-end)
-reads sharing the same id/query name. If all reads in a band are unique
-mappers, they go to the B<basename.uniq.band.bam> file, else all
-reads go the B<basename.mult.band.bam> file.
-
-This routine returns an array holding file names of the newly created
-BAM files for unique and multi mappers, respectively.
-
-NOTE: Not all short read mappers use the I<NH:i:> SAM attribute to
-decorate unique and multi mappers. As such, this routine will not work
-unless your BAM file has these attributes.
-
-=back
-
 =head1 DEPENDENCIES
 
 =over
 
+=item  L<Bio::Perl> >= 1.00690001
+
 =item  L<BIO::DB::Sam> >= 1.37
 
 =item  L<File::Basename>
@@ -662,7 +444,7 @@ unless your BAM file has these attributes.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2017 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2015 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
