@@ -1,14 +1,12 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2014-12-10 15:53:45 mtw>
+# Last changed Time-stamp: <2015-02-11 17:02:53 mtw>
 
 package Bio::ViennaNGS::FeatureChain;
 
-use 5.12.0;
-use version; our $VERSION = qv('0.11');
-
-#use namespace::autoclean;
+use version; our $VERSION = qv('0.12');
 use Moose;
-#use MooseX::InstanceTracking;
+with 'MooseX::Clone';
+use MooseX::InstanceTracking;
 
 has 'type' => (
 	       is => 'rw',
@@ -17,11 +15,11 @@ has 'type' => (
 
 has 'chain' => (
 		is => 'rw',
-		traits => ['Array'],
+		traits => ['Array', 'Clone' => {to=>'ArrayRef'}],
 		isa => 'ArrayRef[Bio::ViennaNGS::Feature]',
 		required => '1',
 		builder => 'build_chain',
-		auto_deref => 1,
+		auto_deref => 1
 		);
 
 sub build_chain {
@@ -50,6 +48,12 @@ sub print_chain{
   return $out;
 }
 
+#sub clone {
+#  my ( $self, %params ) = @_;
+#  $self->meta->clone_object($self, %params);
+#  return $self;
+#}
+
 no Moose;
 
 1;
