@@ -1,13 +1,11 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2017-06-10 19:03:07 michl>
+# Last changed Time-stamp: <2015-02-11 16:16:48 mtw>
 
 package Bio::ViennaNGS::FeatureLine;
 
-use Bio::ViennaNGS;
-use Moose;
+use version; our $VERSION = qv('0.12');
 use namespace::autoclean;
-use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
-
+use Moose;
 extends 'Bio::ViennaNGS::MinimalFeature';
 
 has 'id' => (
