@@ -1,32 +1,25 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2017-06-26 17:28:26 mtw>
+# Last changed Time-stamp: <2015-02-11 17:02:26 mtw>
 
 package Bio::ViennaNGS::UCSC;
 
-use Bio::ViennaNGS;
 use Exporter;
+use version; our $VERSION = qv('0.12');
 use strict;
 use warnings;
 use Template;
 use Cwd;
 use File::Basename;
-use File::Find;
 use IPC::Cmd qw(can_run run);
 use File::Share ':all';
 use Path::Class;
 use Data::Dumper;
 use Carp;
 use Bio::ViennaNGS::Util qw(fetch_chrom_sizes bed2bigBed);
-use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 our @ISA = qw(Exporter);
 
-our @EXPORT_OK = qw( make_assembly_hub make_track_hub retrieve_color
-make_track make_multi_bigwig_container_track
-make_bigwig_container_track retrieve_bigwig_tracks
-retrieve_bigbed_url_tracks parse_fasta_header valid_ncbi_accession
-modify_fasta_header make_group retrieve_chromosome_size
-write_chromosome_size_file convert_tracks);
+our @EXPORT_OK = qw( make_assembly_hub make_track_hub );
 
 our @EXPORT = ();
 
@@ -46,6 +39,10 @@ sub make_assembly_hub{
   croak ("ERROR [$this_function]: no URL (network location for upload to UCSC) provided") 
     unless(defined $baseURL);
 
+  if (defined $log){
+    open(LOG, ">>", $log) or croak "$!";
+  }
+
   unless ($baseURL =~ /\/$/) { $baseURL .= "/"; }
 
   my $tmp_path = dist_file('Bio-ViennaNGS', "hub.txt" );
@@ -70,12 +67,9 @@ sub make_assembly_hub{
   my $genome_assembly_directory = dir($assembly_hub_directory,$genome_assembly_name);
   mkdir $assembly_hub_directory;
   mkdir $genome_assembly_directory;
-
   if (defined $log){
-    open(LOG, ">>", $log) or croak "$!";
     print LOG "LOG Base directory:          $assembly_hub_directory\n";
     print LOG "LOG Assembly Hub directory:  $genome_assembly_directory\n";
-    close(LOG);
   }
 
   #2-bit fasta file conversion
@@ -83,12 +77,7 @@ sub make_assembly_hub{
   modify_fasta_header($fasta_path,$fa_modified,$accession);
   my $twoBit = file($genome_assembly_directory, $accession.".2bit");
   my $fastaToTwobit_cmd = "$faToTwoBit $fa_modified $twoBit";
-
-  if (defined $log){
-    open(LOG, ">>", $log) or croak "$!";
-    print LOG "LOG [$this_function] $fastaToTwobit_cmd\n";
-    close(LOG);
-  }
+  if (defined $log){  print LOG "LOG [$this_function] $fastaToTwobit_cmd\n";}
 
   my( $success, $error_message, $full_buf, $stdout_buf, $stderr_buf ) =
     run( command => $fastaToTwobit_cmd, verbose => 0 );
@@ -186,13 +175,13 @@ sub make_assembly_hub{
     write_chromosome_size_file($chromosome_size_filepath,$accession,$chromosome_size);
     convert_tracks($filesdir, $genome_assembly_directory, $chromosome_size_filepath, $log);
     my @trackfiles = retrieve_tracks($genome_assembly_directory, $baseURL, $assembly_hub_name, $accession);
-
+    
     foreach my $track (@trackfiles){
       my $trackString = make_track(@$track);
       $tracksList .= $trackString;
     }
   }
-
+  
   #big wigs
   my $bigwig_tracks_string = "";
   unless($big_wig_ids=~/^-$/){
@@ -210,7 +199,6 @@ sub make_assembly_hub{
     croak "Template process failed: ", $template->error(), "\n";
 
   if (defined $log){
-    open(LOG, ">>", $log) or croak "$!";
     print LOG "LOG Assembly Hub created\n";
     close(LOG);
   }
@@ -327,26 +315,16 @@ sub make_track_hub{
 
 sub convert_tracks{
   my ($filesdir,$genome_assembly_directory,$chromosome_size_filepath,$log) = @_;
-  my $this_function = (caller(0))[3];
-  my @bedfiles = ();
-
-  find( sub {
-	  return unless -f;
-	  return unless /\.bed$/;
-	  push @bedfiles, $File::Find::name;
-	} , $filesdir);
-
-  if (defined $log){
-    open(LOG, ">>", $log) or croak $!;
-    foreach my $bedfile (@bedfiles){
-      print LOG "LOG [$this_function] found file $bedfile\n";
-    }
-    close(LOG);
-  }
-
+  my $currentDirectory = getcwd;
+  chdir $filesdir or croak $!;
+  my @bedfiles = <*.bed>;
   foreach my $bedfile (@bedfiles){
-    bed2bigBed($bedfile,$chromosome_size_filepath,$genome_assembly_directory,$log);
+    my $bed_file_path = file($filesdir,$bedfile);
+    my $filename = $bedfile;
+    $filename =~ s/.bed$//;
+    bed2bigBed($bed_file_path,$chromosome_size_filepath,$genome_assembly_directory,$log);
   }
+  chdir $currentDirectory or croak $!;
   return 1;
 }
 
@@ -552,13 +530,13 @@ sub make_bigwig_track{
 
 sub valid_ncbi_accession{
   # receives a NCBI accession ID, with or without version number
-  # checks for validity and returns the accession number as is
+  # returns NCBI accession ID without version number
   my $acc = shift;
-  if ($acc =~ /^(N[CSTZ]\_[A-Z]*\d{6})\.\d+?$/){
-    return $acc;
+  if ($acc =~ /^(N[CST]\_\d{6})\.\d+?$/){
+    return $acc; # NCBI accession ID without version
   }
-  elsif ($acc =~ /^(N[CSTZ]\_[A-Z]*\d{6})$/){
-    return $1;
+  elsif ($acc =~ /^(N[CST]\_\d{6})$/){
+    return $1; # NCBI accession ID without version
   }
   else {
     return 0;
@@ -567,27 +545,33 @@ sub valid_ncbi_accession{
 
 sub parse_fasta_header{
   my $filepath = shift;
-  my $this_function = (caller(0))[3];
-  open my $file, '<', "$filepath" or die $!;
+  my $this_function = shift;
+  open my $file, '<', "$filepath";
   my $fastaheader = <$file>;
   chomp $fastaheader;
   close $file;
-  my @ids = ();
   #>gi|556503834|ref|NC_000913.3| Escherichia coli str. K-12 substr. MG1655
   if($fastaheader=~/^>gi/){
+    print LOG "#NCBI fasta header detected\n";
     my @headerfields = split(/\|/, $fastaheader);
     my $accession = $headerfields[3];
     my $scientificName = $headerfields[4];
+    my @ids;
     push(@ids,$accession);
     push(@ids,$scientificName);
     return \@ids;
   }else{
     $fastaheader=~s/^>//;
-    carp "INFO [$this_function] It looks like your input Fasta header does not contain a valid NCBI accession number. Continuing with:\n $fastaheader\n"
-      unless ( valid_ncbi_accession($fastaheader) );
-    push(@ids,$fastaheader);
-    push(@ids,"scientific name not set");
-    return \@ids;
+    if(valid_ncbi_accession($fastaheader)){
+      print LOG "#Header contains just valid NCBI accession number\n";
+      my @ids;
+      push(@ids,$fastaheader);
+      push(@ids,"scientific name not set");
+      return \@ids;
+    }else{
+      print LOG "#No valid accession/ ncbi header\n";
+      croak ("ERROR [$this_function] \$fasta_path does not contain a valid accession/ ncbi header\n");
+    }
   }
 }
 
@@ -596,7 +580,7 @@ sub write_chromosome_size_file{
   my $chromosome_name = shift;
   my $chromosome_size = shift;
   my $entry = $chromosome_name . "\t" . $chromosome_size . "\n";
-  open CHROMFILE, '>', "$filepath" or die $!;
+  open CHROMFILE, '>', "$filepath";
   print CHROMFILE $entry;
   close CHROMFILE;
   return 1;
@@ -606,7 +590,7 @@ sub write_chromosome_sizes_file{
   my $filepath = shift;
   my $chromosome_sizes_reference = shift;
   my %chromosome_sizes = %{$chromosome_sizes_reference};
-  open CHROMFILE, '>', "$filepath" or die $!;
+  open CHROMFILE, '>', "$filepath";
   foreach my $chromosome_name ( keys %chromosome_sizes){
     my $chromosome_size = $chromosome_sizes{$chromosome_name};
     my $entry = $chromosome_name . "\t" . $chromosome_size . "\n";
@@ -685,8 +669,8 @@ Variables:
 
 =head3 make_assembly_hub()
 
-Build an UCSC Genome Browser Assembly Hub. This function takes 4
-parameters:
+Build assembly hubs for the UCSC genome browser.
+This function takes 4 parameters:
 
 =over
 
@@ -694,14 +678,11 @@ parameters:
 
 =item 2 path to the ouput directory (e.g. /home/user/assemblyhubs/)
 
-=item 3 base URL under which the new Assembly Hub will be available on
-the Internet, e.g. http://www.foo.com/folder/. The generated Assembly
-Hub files must be copied to the corresponding file system location on
-the Web Server and the URL readable for the UCSC Genome Browser server.
+=item 3 base URL where the output folder will be placed for upload to the UCSC genome browser (e.g. http://www.foo.com/folder/)
 
 =item 4 path for the log file (/home/user/logs/assemblyhubconstructionlog)
 
-=back
+back
 
 =head3 make_track_hub()
 
@@ -740,7 +721,7 @@ This function takes 4 parameters:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2017 Michael T. Wolfinger, E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2015 Michael T. Wolfinger, E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
